import Vue from 'vue';
import moment from 'moment';
function isDark(hexcolor: string) {
    const r = parseInt(hexcolor.substr(0, 2), 16);
    const g = parseInt(hexcolor.substr(2, 2), 16);
    const b = parseInt(hexcolor.substr(4, 2), 16);
    const yiq = (r * 299 + g * 587 + b * 114) / 1000;
    return yiq >= 128 ? false : true;
}

Vue.filter('isDark', (v: string) => {
    return isDark(v.replace('#', ''));
});

Vue.filter(
    'formatTime',
    (val: any, format: string = 'DD/MM/YY HH:mm', base: string) => {
        if (val === '') {
            return '';
        }
        return moment(val, base).format(format);
    },
);

Vue.filter('currency', (val: any) => {
    return typeof val === 'number'
        ? val.toFixed(2)
        : parseInt(val, 0).toFixed(2);
});

Vue.filter('timelineIcon', (val: string) => {
    switch (val.toLowerCase()) {
        case 'title':
            return 'mdi-calendar';
        case 'comment':
            return 'mdi-comment-text';
        case 'activity':
            return 'mdi-plus';
        case 'change':
            return 'mdi-autorenew';
        case 'reassignment':
            return 'mdi-account-convert';
        default:
            return 'mdi-minus';
    }
});

export const thumb = (val: string, size: any = 'w_80') => {
    if (val) {
        const base = val
            .split('/')
            .reverse()
            .slice(2)
            .reverse()
            .concat([`${size},c_thumb`], val.split('/').slice(-2))
            .join('/');

        return base;
    } else {
        return '';
    }
};

Vue.filter('thumb', thumb);
